.. _help:

Help Needed
--------------

We are looking for contributions to enhance **Locust Telemetry** with
OpenTelemetry traces and spans for load testing.

**Current Status**

- JSON telemetry and OpenTelemetry metrics are supported.
- Traces and spans for request-level operations are **not yet implemented**.
- Contributions would help us correlate requests, users, and system metrics
  across the load test in a traceable manner.

**What We Need**

- Implement OpenTelemetry trace and span creation for Locust
  Tasks and virtual users.
